public inbox for isar-users@googlegroups.com
 help / color / mirror / Atom feed
From: Henning Schild <henning.schild@siemens.com>
To: isar-users@googlegroups.com
Cc: Henning Schild <henning.schild@siemens.com>
Subject: [PATCH] CI: install avocado debian packages from isar-build.org
Date: Fri, 22 Oct 2021 09:57:37 +0200	[thread overview]
Message-ID: <20211022075737.6993-1-henning.schild@siemens.com> (raw)
In-Reply-To: <1634885470-19422-1-git-send-email-amikan@ilbers.de>

Might be better than doing it with pip. So we only need to maintain one
path while waiting for upsteam debian to ship packages.

Signed-off-by: Henning Schild <henning.schild@siemens.com>
---
 scripts/ci_build.sh | 14 ++++++++------
 1 file changed, 8 insertions(+), 6 deletions(-)

diff --git a/scripts/ci_build.sh b/scripts/ci_build.sh
index 5ff455e3d77b..ddec9e38cb87 100755
--- a/scripts/ci_build.sh
+++ b/scripts/ci_build.sh
@@ -14,14 +14,16 @@ export PATH=$PATH:/sbin
 # Go to Isar root
 cd "$(dirname "$0")/.."
 
 # install avocado in virtualenv in case it is not there already
 if ! command -v avocado > /dev/null; then
     sudo apt-get update -qq
-    sudo apt-get install -y virtualenv
-    rm -rf /tmp/avocado_venv
-    virtualenv --python python3 /tmp/avocado_venv
-    source /tmp/avocado_venv/bin/activate
-    pip install avocado-framework
+    sudo apt-get install gnupg2 lsb-release curl -y
+    codename=$( lsb_release -cs )
+    curl http://deb.isar-build.org/debian-isar.key --output /tmp/isar-gpg.pub
+    sudo apt-key add /tmp/isar-gpg.pub
+    echo "deb http://deb.isar-build.org/debian-isar $codename-isar main" | sudo tee /etc/apt/sources.list.d/isar.list > /dev/null
+    sudo apt-get update -qq
+    sudo apt-get install -y avocado
 fi
 
 # Get Avocado build tests path
@@ -14,14 +14,16 @@ export PATH=$PATH:/sbin
 cd "$(dirname "$0")/.."
 
-# install avocado in virtualenv in case it is not there already
+# install avocado in from deb.isar-build.org in case it is not there already
 if ! command -v avocado > /dev/null; then
     sudo apt-get update -qq
-- 
2.32.0


  reply	other threads:[~2021-10-22  7:57 UTC|newest]

Thread overview: 7+ messages / expand[flat|nested]  mbox.gz  Atom feed  top
2021-10-22  6:51 [PATCH] CI: Fix paths for the latest Avocado version Anton Mikanovich
2021-10-22  7:57 ` Henning Schild [this message]
2021-10-22  7:59   ` [PATCH] CI: install avocado debian packages from isar-build.org Henning Schild
2021-10-22  8:08   ` Henning Schild
2021-10-26  7:37   ` Anton Mikanovich
2021-10-26  8:02     ` Henning Schild
2021-11-02 16:21 ` [PATCH] CI: Fix paths for the latest Avocado version Anton Mikanovich

Reply instructions:

You may reply publicly to this message via plain-text email
using any one of the following methods:

* Save the following mbox file, import it into your mail client,
  and reply-to-all from there: mbox

  Avoid top-posting and favor interleaved quoting:
  https://en.wikipedia.org/wiki/Posting_style#Interleaved_style

* Reply using the --to, --cc, and --in-reply-to
  switches of git-send-email(1):

  git send-email \
    --in-reply-to=20211022075737.6993-1-henning.schild@siemens.com \
    --to=henning.schild@siemens.com \
    --cc=isar-users@googlegroups.com \
    /path/to/YOUR_REPLY

  https://kernel.org/pub/software/scm/git/docs/git-send-email.html

* If your mail client supports setting the In-Reply-To header
  via mailto: links, try the mailto: link
Be sure your reply has a Subject: header at the top and a blank line before the message body.
This is a public inbox, see mirroring instructions
for how to clone and mirror all data and code used for this inbox